@@ -1,8 +1,7 @@
-#! coding = utf-8
 import logging
 import sqlite3
-
 from persistqueue import sqlbase
+from typing import Any, Iterator
 
 log = logging.getLogger(__name__)
 
@@ -16,54 +15,64 @@ class PDict(sqlbase.SQLiteBase, dict):
     _SQL_SELECT = ('SELECT {key_column}, data FROM {table_name} '
                    'WHERE {key_column} = ?')
     _SQL_UPDATE = 'UPDATE {table_name} SET data = ? WHERE {key_column} = ?'
+    _SQL_DELETE = 'DELETE FROM {table_name} WHERE {key_column} {op} ?'
 
-    def __init__(self, path, name, multithreading=False):
+    def __init__(self,
+                 path: str,
+                 name: str,
+                 multithreading: bool = False) -> None:
         # PDict is always auto_commit=True
-        super(PDict, self).__init__(path, name=name,
-                                    multithreading=multithreading,
-                                    auto_commit=True)
+        super().__init__(path, name=name,
+                         multithreading=multithreading,
+                         auto_commit=True)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator:
         raise NotImplementedError('Not supported.')
 
-    def keys(self):
+    def keys(self) -> Iterator:
         raise NotImplementedError('Not supported.')
 
-    def iterkeys(self):
+    def iterkeys(self) -> Iterator:
         raise NotImplementedError('Not supported.')
 
-    def values(self):
+    def values(self) -> Iterator:
         raise NotImplementedError('Not supported.')
 
-    def itervalues(self):
+    def itervalues(self) -> Iterator:
         raise NotImplementedError('Not supported.')
 
-    def iteritems(self):
+    def iteritems(self) -> Iterator:
         raise NotImplementedError('Not supported.')
 
-    def items(self):
+    def items(self) -> Iterator:
         raise NotImplementedError('Not supported.')
 
-    def __contains__(self, item):
+    def __contains__(self, item: Any) -> bool:
         row = self._select(item)
         return row is not None
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key: Any, value: Any) -> None:
         obj = self._serializer.dumps(value)
         try:
             self._insert_into(key, obj)
         except sqlite3.IntegrityError:
             self._update(key, obj)
 
-    def __getitem__(self, item):
+    def __getitem__(self, item: Any) -> Any:
         row = self._select(item)
         if row:
             return self._serializer.loads(row[1])
         else:
             raise KeyError('Key: {} not exists.'.format(item))
 
-    def __delitem__(self, key):
+    def get(self, key: Any, default: Any = None) -> Any:
+        try:
+            return self[key]
+        except KeyError:
+            return default
+
+    def __delitem__(self, key: Any) -> None:
         self._delete(key)
 
-    def __len__(self):
+    def __len__(self) -> int:
         return self._count()
